# Generated by roxygen2: do not edit by hand

export(add_insee_metadata)
export(add_insee_title)
export(get_column_title)
export(get_dataset_list)
export(get_idbank_list)
export(get_insee)
export(get_insee_dataset)
export(get_insee_idbank)
export(get_insee_title)
export(search_insee)
export(split_title)
importFrom(rlang,.data)
